summaryrefslogtreecommitdiff
path: root/src/mongo/db/exec/working_set.h
diff options
context:
space:
mode:
authorMathias Stearn <mathias@10gen.com>2014-11-26 15:04:26 -0500
committerMathias Stearn <mathias@10gen.com>2014-11-26 15:15:59 -0500
commit16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8 (patch)
tree2d9f056acf8f1b9b2e943f82e315bdf019475a38 /src/mongo/db/exec/working_set.h
parentcb5cab88761d9aca75e064665cce89f579c69e36 (diff)
downloadmongo-16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8.tar.gz
SERVER-13679 Replace DiskLoc with RecordId outside of MMAPv1
Operations: sed -i -e 's/\<DiskLoc\>/RecordId/g' sed -i -e 's/\<DiskLocs\>/RecordIds/g' sed -i -e 's/\<minDiskLoc\>/RecordId::min()/g' sed -i -e 's/\<maxDiskLoc\>/RecordId::max()/g' sed -i -e 's/\<getDiskLoc\>/getRecordId/g'' Changes under mmap_v1 were reverted and redone by hand as needed.
Diffstat (limited to 'src/mongo/db/exec/working_set.h')
-rw-r--r--src/mongo/db/exec/working_set.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/exec/working_set.h b/src/mongo/db/exec/working_set.h
index 287198a1cf7..bcdea8f2cf9 100644
--- a/src/mongo/db/exec/working_set.h
+++ b/src/mongo/db/exec/working_set.h
@@ -84,7 +84,7 @@ namespace mongo {
void free(const WorkingSetID& i);
/**
* The DiskLoc in WSM 'i' was invalidated while being processed. Any predicates over the
* WSM could not be fully evaluated, so the WSM may or may not satisfy them. As such, if we
* wish to output the WSM, we must do some clean-up work later. Adds the WSM with id 'i' to
* the list of flagged WSIDs.
@@ -217,7 +217,7 @@ namespace mongo {
// Data is from a collection scan, or data is from an index scan and was fetched.
LOC_AND_UNOWNED_OBJ,
// DiskLoc has been invalidated, or the obj doesn't correspond to an on-disk document
// anymore (e.g. is a computed expression).
OWNED_OBJ,
};
@@ -226,7 +226,7 @@ namespace mongo {
// Core attributes
//
- DiskLoc loc;
+ RecordId loc;
BSONObj obj;
std::vector<IndexKeyDatum> keyData;
MemberState state;
@@ -84,7 +84,7 @@ namespace mongo {
void free(const WorkingSetID& i);
/**
- * The DiskLoc in WSM 'i' was invalidated while being processed. Any predicates over the
+ * The RecordId in WSM 'i' was invalidated while being processed. Any predicates over the
* WSM could not be fully evaluated, so the WSM may or may not satisfy them. As such, if we
* wish to output the WSM, we must do some clean-up work later. Adds the WSM with id 'i' to
@@ -217,7 +217,7 @@ namespace mongo {
// Data is from a collection scan, or data is from an index scan and was fetched.
LOC_AND_UNOWNED_OBJ,
- // DiskLoc has been invalidated, or the obj doesn't correspond to an on-disk document
+ // RecordId has been invalidated, or the obj doesn't correspond to an on-disk document
// anymore (e.g. is a computed expression).
OWNED_OBJ,